@@ -19,7 +19,7 @@ class CallBack(object):
 		The method to get the url
 
 		Returns:
-			string: A string value
+			string: A string representing the url
 		"""
 
 		return self.__url
@@ -70,7 +70,7 @@ class CallBack(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
