@@ -25,7 +25,7 @@ class JobDetail(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -49,7 +49,7 @@ class JobDetail(object):
 		The method to get the operation
 
 		Returns:
-			string: A string value
+			string: A string representing the operation
 		"""
 
 		return self.__operation
@@ -210,7 +210,7 @@ class JobDetail(object):
 		The method to get the file_type
 
 		Returns:
-			string: A string value
+			string: A string representing the file_type
 		"""
 
 		return self.__file_type
@@ -237,7 +237,7 @@ class JobDetail(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
