@@ -1,5 +1,5 @@
 from .action_wrapper import ActionWrapper
-from .file_operations import FileOperations, UploadFileParam, GetFileParam
+from .file_operations import FileOperations, UploadFilesParam, GetFileParam
 from .api_exception import APIException
 from .response_handler import ResponseHandler
 from .action_response import ActionResponse
