@@ -1,7 +1,7 @@
 from .layout import Layout
 from .api_exception import APIException
 from .response_handler import ResponseHandler
-from .layouts_operations import LayoutsOperations
+from .layouts_operations import LayoutsOperations, GetLayoutsParam, GetLayoutParam
 from .response_wrapper import ResponseWrapper
 from .section import Section
 from .properties import Properties
