@@ -35,7 +35,7 @@ class QueryOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/coql'
+		api_path = api_path + '/crm/v2.1/coql'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_CREATE)
