@@ -26,7 +26,7 @@ class Field(object):
 		The method to get the api_name
 
 		Returns:
-			string: A string value
+			string: A string representing the api_name
 		"""
 
 		return self.__api_name
