@@ -50,7 +50,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -59,7 +59,7 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
@@ -99,7 +99,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -108,7 +108,7 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
-		Utility.get_fields(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
@@ -143,7 +143,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -184,14 +184,14 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
 		handler_instance.set_header(header_instance)
-		Utility.get_fields(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
@@ -227,7 +227,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
@@ -235,7 +235,7 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
@@ -271,7 +271,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_PUT)
@@ -279,7 +279,7 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
@@ -310,7 +310,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_DELETE)
@@ -350,7 +350,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/upsert'
 		handler_instance.set_api_path(api_path)
@@ -358,7 +358,7 @@ class RecordOperations(object):
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_ACTION)
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
-		Utility.get_fields(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
@@ -393,7 +393,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/deleted'
 		handler_instance.set_api_path(api_path)
@@ -430,14 +430,14 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/search'
 		handler_instance.set_api_path(api_path)
 		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
 		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
 		handler_instance.set_param(param_instance)
-		Utility.get_fields(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.response_handler import ResponseHandler
@@ -473,7 +473,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/Leads/'
+		api_path = api_path + '/crm/v2.1/Leads/'
 		api_path = api_path + str(id)
 		api_path = api_path + '/actions/convert'
 		handler_instance.set_api_path(api_path)
@@ -482,7 +482,7 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields("Deals")
+		Utility.get_fields("Deals", handler_instance)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.convert_action_handler import ConvertActionHandler
 		except Exception:
@@ -512,7 +512,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -558,7 +558,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -569,6 +569,7 @@ class RecordOperations(object):
 		handler_instance.set_content_type('multipart/form-data')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
+		Utility.verify_photo_support(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.file_handler import FileHandler
 		except Exception:
@@ -598,7 +599,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(id)
@@ -640,7 +641,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/mass_update'
 		handler_instance.set_api_path(api_path)
@@ -649,7 +650,7 @@ class RecordOperations(object):
 		handler_instance.set_content_type('application/json')
 		handler_instance.set_request(request)
 		handler_instance.set_mandatory_checker(True)
-		Utility.get_fields(module_api_name)
+		Utility.get_fields(module_api_name, handler_instance)
 		handler_instance.set_module_api_name(module_api_name)
 		try:
 			from zcrmsdk.src.com.zoho.crm.api.record.mass_update_action_handler import MassUpdateActionHandler
@@ -680,7 +681,7 @@ class RecordOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(module_api_name)
 		api_path = api_path + '/actions/mass_update'
 		handler_instance.set_api_path(api_path)
@@ -693,6 +694,232 @@ class RecordOperations(object):
 			from .mass_update_response_handler import MassUpdateResponseHandler
 		return handler_instance.api_call(MassUpdateResponseHandler.__module__, 'application/json')
 
+	def assign_territories_to_multiple_records(self, module_api_name, request):
+		"""
+		The method to assign territories to multiple records
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/actions/assign_territories'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
+		Utility.get_fields(module_api_name, handler_instance)
+		handler_instance.set_module_api_name(module_api_name)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def assign_territory_to_record(self, module_api_name, id, request):
+		"""
+		The method to assign territory to record
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
+			request (BodyWrapper) : An instance of BodyWrapper
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/'
+		api_path = api_path + str(id)
+		api_path = api_path + '/actions/assign_territories'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		Utility.get_fields(module_api_name, handler_instance)
+		handler_instance.set_module_api_name(module_api_name)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def remove_territories_from_multiple_records(self, module_api_name, request):
+		"""
+		The method to remove territories from multiple records
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			request (BodyWrapper) : An instance of BodyWrapper
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/actions/remove_territories'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		handler_instance.set_mandatory_checker(True)
+		Utility.get_fields(module_api_name, handler_instance)
+		handler_instance.set_module_api_name(module_api_name)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def remove_territories_from_record(self, module_api_name, id, request):
+		"""
+		The method to remove territories from record
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			id (int) : An int representing the id
+			request (BodyWrapper) : An instance of BodyWrapper
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.body_wrapper import BodyWrapper
+		except Exception:
+			from .body_wrapper import BodyWrapper
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if not isinstance(id, int):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
+		
+		if request is not None and not isinstance(request, BodyWrapper):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/'
+		api_path = api_path + str(id)
+		api_path = api_path + '/actions/remove_territories'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_POST)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_UPDATE)
+		handler_instance.set_content_type('application/json')
+		handler_instance.set_request(request)
+		Utility.get_fields(module_api_name, handler_instance)
+		handler_instance.set_module_api_name(module_api_name)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.action_handler import ActionHandler
+		except Exception:
+			from .action_handler import ActionHandler
+		return handler_instance.api_call(ActionHandler.__module__, 'application/json')
+
+	def record_count(self, module_api_name, param_instance=None):
+		"""
+		The method to record count
+
+		Parameters:
+			module_api_name (string) : A string representing the module_api_name
+			param_instance (ParameterMap) : An instance of ParameterMap
+
+		Returns:
+			APIResponse: An instance of APIResponse
+
+		Raises:
+			SDKException
+		"""
+
+		if not isinstance(module_api_name, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
+		
+		if param_instance is not None and not isinstance(param_instance, ParameterMap):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
+		
+		handler_instance = CommonAPIHandler()
+		api_path = ''
+		api_path = api_path + '/crm/v2.1/'
+		api_path = api_path + str(module_api_name)
+		api_path = api_path + '/actions/count'
+		handler_instance.set_api_path(api_path)
+		handler_instance.set_http_method(Constants.REQUEST_METHOD_GET)
+		handler_instance.set_category_method(Constants.REQUEST_CATEGORY_READ)
+		handler_instance.set_param(param_instance)
+		try:
+			from zcrmsdk.src.com.zoho.crm.api.record.count_handler import CountHandler
+		except Exception:
+			from .count_handler import CountHandler
+		return handler_instance.api_call(CountHandler.__module__, 'application/json')
+
 
 class GetRecordParam(object):
 	approved = Param('approved', 'com.zoho.crm.api.Record.GetRecordParam')
@@ -763,3 +990,10 @@ class SearchRecordsParam(object):
 
 class GetMassUpdateStatusParam(object):
 	job_id = Param('job_id', 'com.zoho.crm.api.Record.GetMassUpdateStatusParam')
+
+
+class RecordCountParam(object):
+	criteria = Param('criteria', 'com.zoho.crm.api.Record.RecordCountParam')
+	email = Param('email', 'com.zoho.crm.api.Record.RecordCountParam')
+	phone = Param('phone', 'com.zoho.crm.api.Record.RecordCountParam')
+	word = Param('word', 'com.zoho.crm.api.Record.RecordCountParam')
