@@ -62,7 +62,7 @@ class RelatedRecordsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(self.__module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(self.__record_id)
@@ -104,7 +104,7 @@ class RelatedRecordsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(self.__module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(self.__record_id)
@@ -142,7 +142,7 @@ class RelatedRecordsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(self.__module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(self.__record_id)
@@ -181,7 +181,7 @@ class RelatedRecordsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(self.__module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(self.__record_id)
@@ -228,7 +228,7 @@ class RelatedRecordsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(self.__module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(self.__record_id)
@@ -267,7 +267,7 @@ class RelatedRecordsOperations(object):
 		
 		handler_instance = CommonAPIHandler()
 		api_path = ''
-		api_path = api_path + '/crm/v2/'
+		api_path = api_path + '/crm/v2.1/'
 		api_path = api_path + str(self.__module_api_name)
 		api_path = api_path + '/'
 		api_path = api_path + str(self.__record_id)
