@@ -25,7 +25,7 @@ class Role(object):
 		The method to get the display_label
 
 		Returns:
-			string: A string value
+			string: A string representing the display_label
 		"""
 
 		return self.__display_label
@@ -78,7 +78,7 @@ class Role(object):
 		The method to get the share_with_peers
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the share_with_peers
 		"""
 
 		return self.__share_with_peers
@@ -102,7 +102,7 @@ class Role(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -126,7 +126,7 @@ class Role(object):
 		The method to get the description
 
 		Returns:
-			string: A string value
+			string: A string representing the description
 		"""
 
 		return self.__description
@@ -150,7 +150,7 @@ class Role(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -203,7 +203,7 @@ class Role(object):
 		The method to get the admin_user
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the admin_user
 		"""
 
 		return self.__admin_user
@@ -230,7 +230,7 @@ class Role(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
