@@ -19,7 +19,7 @@ class Preference(object):
 		The method to get the auto_populate_tax
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the auto_populate_tax
 		"""
 
 		return self.__auto_populate_tax
@@ -43,7 +43,7 @@ class Preference(object):
 		The method to get the modify_tax_rates
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the modify_tax_rates
 		"""
 
 		return self.__modify_tax_rates
@@ -70,7 +70,7 @@ class Preference(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
