@@ -178,15 +178,4 @@ class FormDataConverter(Converter):
     def construct_private_member(class_name, member_name):
         return '_' + class_name + '__' + member_name
 
-    @staticmethod
-    def module_to_class(module_name):
-        class_name = module_name
 
-        if "_" in module_name:
-            class_name = ''
-            module_split = str(module_name).split('_')
-            for each_name in module_split:
-                each_name = each_name.capitalize()
-                class_name += each_name
-
-        return class_name
