@@ -36,7 +36,7 @@ class HeaderParamValidator(object):
                 from zcrmsdk.src.com.zoho.crm.api.util.utility import Utility
             except Exception:
                 from ..util.utility import Utility
-            if not Utility.check_data_type(type_detail[Constants.TYPE], value):
+            if not Utility.check_data_type(value, type_detail[Constants.TYPE]):
                 param_or_header = 'PARAMETER' if json_class_name is not None and json_class_name.endswith('Param') else 'HEADER'
                 error_details = {
                     param_or_header: name,
