@@ -587,8 +587,7 @@ class JSONConverter(Converter):
             import os
             from ..initializer import Initializer
 
-        record_field_details_path = os.path.join(Initializer.get_initializer().resource_path,
-                                                 Constants.FIELD_DETAILS_DIRECTORY, Converter.get_encoded_file_name())
+        record_field_details_path = os.path.join(Initializer.get_initializer().resource_path,Constants.FIELD_DETAILS_DIRECTORY, Converter.get_encoded_file_name())
 
         record_field_details = Initializer.get_json(record_field_details_path)
         module_detail = Utility.get_json_object(record_field_details, module)
