@@ -4,7 +4,7 @@ from .node import Node
 from .api_exception import APIException
 from .response_handler import ResponseHandler
 from .chart_data import ChartData
-from .wizards_operations import WizardsOperations, GetWizardsParam, GetWizardbyIDParam
+from .wizards_operations import WizardsOperations, GetWizardbyIDParam
 from .segment import Segment
 from .screen import Screen
 from .response_wrapper import ResponseWrapper
